@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2017 David Mohammed
+# Copyright (C) 2015 - 2018 David Mohammed <fossfreedom@ubuntu.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1433,12 +1433,12 @@ class AltToolbarHeaderBar(AltToolbarShared):
         if not song_label:
             self.library_song_radiobutton.set_label(_('Songs'))
         else:
-            self.library_song_radiobutton.set_label(song_label)
+            self.library_song_radiobutton.set_label(cl.get_translation(song_label))
 
         if not category_label:
             self.library_browser_radiobutton.set_label(_('Categories'))
         else:
-            self.library_browser_radiobutton.set_label(category_label)
+            self.library_browser_radiobutton.set_label(cl.get_translation(category_label))
 
         cl.switch_locale(cl.Locale.RB)
 
@@ -1542,6 +1542,18 @@ class AltToolbarHeaderBar(AltToolbarShared):
         # any source defined controls
         self._end_box_controls.add(self.end_box)
 
+        # add a source toggle button
+        source_button = Gtk.ToggleButton.new()
+        source_button.set_action_name("app.ToggleSourceMediaToolbar")
+
+        symbol = "view-more-horizontal-symbolic"
+        source_button.set_margin_left(3)
+
+        image = Gtk.Image.new_from_icon_name(symbol,
+                                             Gtk.IconSize.SMALL_TOOLBAR)
+        source_button.add(image)
+        self._end_box_controls.add(source_button)
+
         # GNOME design upstream is that main appmenu options should be
         # within reach of the headerbar with the traditional
         # appmenu reduced to the occasionally used options
